@@ -10,7 +10,7 @@ from .amount import Amount
 
 
 __author__ = 'Qingxu Kuang<kuangqingxu@transfereasy.com>'
-__version__ = '1.0.5'
+__version__ = '1.0.6'
 
 
 class Money(object):
@@ -111,3 +111,17 @@ class Money(object):
 
     def __le__(self, other):
         return (self == other) or (self < other)
+
+    def exchange(self, forex_rate):
+
+        if self.currency != forex_rate.base_currency:
+            raise ValueError(
+                f'{self.currency.iso_code} Not Equals {forex_rate.base_currency.iso_code}'
+            )
+
+        amount = self.amount.exchange(forex_rate)
+
+        return Money(
+            currency=forex_rate.target_currency,
+            amount=amount
+        )
